@@ -1,6 +1,8 @@
+import functools
 import os
+import sys
 from pathlib import Path
-from typing import Iterable, Union
+from typing import Callable, Iterable, Union
 
 from amora.config import settings
 
@@ -32,3 +34,14 @@ def clean_compiled_files() -> None:
 
 def list_target_files() -> Iterable[Path]:
     return list_files(settings.target_path, suffix=".sql")
+
+
+def ensure_path(func: Callable) -> Callable:
+    if settings.models_path not in sys.path:
+        sys.path.append(settings.models_path.as_posix())
+
+    @functools.wraps(func)
+    def wrapper(*args, **kwargs):
+        return func(*args, **kwargs)
+
+    return wrapper
